/**
 * Copyright 2014-present Palantir Technologies
 * @license MIT
 */
"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var d3 = require("d3");
var drawer_1 = require("./drawer");
var Line = (function (_super) {
    __extends(Line, _super);
    /**
     * @param dataset
     * @param _d3LineFactory A callback that gives this Line Drawer a d3.Line object which will be
     * used to draw with.
     */
    function Line(dataset, d3LineFactory) {
        var _this = _super.call(this, dataset) || this;
        _this._d3LineFactory = d3LineFactory;
        _this._className = "line";
        _this._svgElementName = "path";
        return _this;
    }
    Line.prototype._applyDefaultAttributes = function (selection) {
        _super.prototype._applyDefaultAttributes.call(this, selection);
        selection.style("fill", "none");
    };
    Line.prototype.selectionForIndex = function (index) {
        return d3.select(this.selection().node());
    };
    /**
     *
     * @param data Data to draw. The data will be passed through the line factory in order to get applied
     * onto the canvas.
     * @param step
     * @private
     */
    Line.prototype._drawStepCanvas = function (data, step) {
        var context = this.canvas().node().getContext("2d");
        var d3Line = this._d3LineFactory();
        var attrToAppliedProjector = step.attrToAppliedProjector;
        var resolvedAttrs = Object.keys(attrToAppliedProjector).reduce(function (obj, attrName) {
            obj[attrName] = attrToAppliedProjector[attrName](data, 0);
            return obj;
        }, {});
        context.save();
        context.beginPath();
        d3Line.context(context);
        d3Line(data[0]);
        if (resolvedAttrs["stroke-width"]) {
            context.lineWidth = parseFloat(resolvedAttrs["stroke-width"]);
        }
        if (resolvedAttrs["stroke"]) {
            var strokeColor = d3.color(resolvedAttrs["stroke"]);
            if (resolvedAttrs["opacity"]) {
                strokeColor.opacity = resolvedAttrs["opacity"];
            }
            context.strokeStyle = strokeColor.rgb().toString();
            context.stroke();
        }
        context.restore();
    };
    return Line;
}(drawer_1.Drawer));
exports.Line = Line;
