"use strict";
var chai_1 = require("chai");
var Plottable = require("../../src");
describe("Dataset", function () {
    it("Updates listeners when the data is changed", function () {
        var ds = new Plottable.Dataset();
        var newData = [1, 2, 3];
        var callbackCalled = false;
        var callback = function (listenable) {
            chai_1.assert.strictEqual(listenable, ds, "Callback received the Dataset as the first argument");
            chai_1.assert.deepEqual(ds.data(), newData, "Dataset arrives with correct data");
            callbackCalled = true;
        };
        ds.onUpdate(callback);
        ds.data(newData);
        chai_1.assert.isTrue(callbackCalled, "callback was called when the data was changed");
    });
    it("Updates listeners when the metadata is changed", function () {
        var ds = new Plottable.Dataset();
        var newMetadata = "blargh";
        var callbackCalled = false;
        var callback = function (listenable) {
            chai_1.assert.strictEqual(listenable, ds, "Callback received the Dataset as the first argument");
            chai_1.assert.deepEqual(ds.metadata(), newMetadata, "Dataset arrives with correct metadata");
            callbackCalled = true;
        };
        ds.onUpdate(callback);
        ds.metadata(newMetadata);
        chai_1.assert.isTrue(callbackCalled, "callback was called when the metadata was changed");
    });
    it("Removing listener from dataset should be possible", function () {
        var ds = new Plottable.Dataset();
        var newData1 = [1, 2, 3];
        var newData2 = [4, 5, 6];
        var callbackCalled = false;
        var callback = function (listenable) {
            chai_1.assert.strictEqual(listenable, ds, "Callback received the Dataset as the first argument");
            callbackCalled = true;
        };
        ds.onUpdate(callback);
        ds.data(newData1);
        chai_1.assert.isTrue(callbackCalled, "callback was called when the data was changed");
        callbackCalled = false;
        ds.offUpdate(callback);
        ds.data(newData2);
        chai_1.assert.isFalse(callbackCalled, "callback was called when the data was changed");
    });
});
