"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var d3 = require("d3");
var chai_1 = require("chai");
var Plottable = require("../../src");
var TestMethods = require("../testMethods");
describe("Dispatchers", function () {
    describe("Dispatcher", function () {
        var InstrumentedDispatcher = (function (_super) {
            __extends(InstrumentedDispatcher, _super);
            function InstrumentedDispatcher() {
                var _this = _super.call(this) || this;
                _this._eventToProcessingFunction[InstrumentedDispatcher.EVENT_NAME] =
                    function () { return _this._callCallbacksForEvent(InstrumentedDispatcher.EVENT_NAME); };
                return _this;
            }
            InstrumentedDispatcher.prototype.addCallback = function (callback) {
                this._addCallbackForEvent(InstrumentedDispatcher.EVENT_NAME, callback);
            };
            InstrumentedDispatcher.prototype.removeCallback = function (callback) {
                this._removeCallbackForEvent(InstrumentedDispatcher.EVENT_NAME, callback);
            };
            return InstrumentedDispatcher;
        }(Plottable.Dispatcher));
        InstrumentedDispatcher.EVENT_NAME = "instrumented";
        var TEST_EVENT_NAME = "test";
        it("connects and disconnects correctly", function () {
            var dispatcher = new Plottable.Dispatcher();
            var callbackCalled = false;
            dispatcher._eventToProcessingFunction[TEST_EVENT_NAME] = function () { return callbackCalled = true; };
            var d3document = d3.select(document);
            dispatcher._connect();
            TestMethods.triggerFakeUIEvent(TEST_EVENT_NAME, d3document);
            chai_1.assert.isTrue(callbackCalled, "connected correctly (callback was called)");
            dispatcher._connect();
            callbackCalled = false;
            TestMethods.triggerFakeUIEvent(TEST_EVENT_NAME, d3document);
            chai_1.assert.isTrue(callbackCalled, "can't double-connect (callback only called once)");
            dispatcher._disconnect();
            callbackCalled = false;
            TestMethods.triggerFakeUIEvent(TEST_EVENT_NAME, d3document);
            chai_1.assert.isFalse(callbackCalled, "disconnected correctly (callback not called)");
        });
        it("won't disconnect if it still has listeners", function () {
            var dispatcher = new InstrumentedDispatcher();
            var processingFunctionWasCalled = false;
            dispatcher._eventToProcessingFunction[TEST_EVENT_NAME] = function () { return processingFunctionWasCalled = true; };
            var callback = function () { return; };
            dispatcher.addCallback(callback);
            var d3document = d3.select(document);
            dispatcher._connect();
            TestMethods.triggerFakeUIEvent(TEST_EVENT_NAME, d3document);
            chai_1.assert.isTrue(processingFunctionWasCalled, "connected correctly (processing function was called)");
            dispatcher._disconnect();
            processingFunctionWasCalled = false;
            TestMethods.triggerFakeUIEvent(TEST_EVENT_NAME, d3document);
            chai_1.assert.isTrue(processingFunctionWasCalled, "didn't disconnect while dispatcher had listener");
            dispatcher.removeCallback(callback);
            dispatcher._disconnect();
            processingFunctionWasCalled = false;
            TestMethods.triggerFakeUIEvent(TEST_EVENT_NAME, d3document);
            chai_1.assert.isFalse(processingFunctionWasCalled, "disconnected when dispatcher had no listeners");
        });
        it("can set and unset callbacks", function () {
            var dispatcher = new InstrumentedDispatcher();
            var callbackWasCalled = false;
            var callback = function () { return callbackWasCalled = true; };
            dispatcher.addCallback(callback);
            var d3document = d3.select(document);
            TestMethods.triggerFakeUIEvent(InstrumentedDispatcher.EVENT_NAME, d3document);
            chai_1.assert.isTrue(callbackWasCalled, "callback was called after being added");
            dispatcher.removeCallback(callback);
            callbackWasCalled = false;
            TestMethods.triggerFakeUIEvent(InstrumentedDispatcher.EVENT_NAME, d3document);
            chai_1.assert.isFalse(callbackWasCalled, "callback was not called after removal");
        });
    });
});
