"use strict";
var d3 = require("d3");
var chai_1 = require("chai");
var Plottable = require("../../src");
var TestMethods = require("../testMethods");
describe("Dispatchers", function () {
    describe("Key Dispatcher", function () {
        describe("Basic usage", function () {
            var keyCodeToSend;
            var keyDispatcher;
            var body;
            beforeEach(function () {
                keyCodeToSend = 65;
                keyDispatcher = Plottable.Dispatchers.Key.getDispatcher();
                body = d3.select("body");
            });
            it("can set a callback to be called when a key is pressed down", function () {
                var keyDowned = false;
                var callback = function (code, event) {
                    keyDowned = true;
                    chai_1.assert.strictEqual(code, keyCodeToSend, "correct keycode was passed");
                    chai_1.assert.isNotNull(event, "key event was passed to the callback");
                };
                chai_1.assert.strictEqual(keyDispatcher.onKeyDown(callback), keyDispatcher, "setting the keyDown callback returns the dispatcher");
                TestMethods.triggerFakeKeyboardEvent("keydown", body, keyCodeToSend);
                chai_1.assert.isTrue(keyDowned, "callback when a key was pressed");
                keyDispatcher.offKeyDown(callback);
            });
            it("can remove the keydown listener", function () {
                var keyDowned = false;
                var callback = function () { return keyDowned = true; };
                keyDispatcher.onKeyDown(callback);
                TestMethods.triggerFakeKeyboardEvent("keydown", body, keyCodeToSend);
                chai_1.assert.isTrue(keyDowned, "callback when a key was pressed");
                chai_1.assert.strictEqual(keyDispatcher.offKeyDown(callback), keyDispatcher, "unsetting the keyDown callback returns the dispatcher");
                keyDowned = false;
                TestMethods.triggerFakeKeyboardEvent("keydown", body, keyCodeToSend);
                chai_1.assert.isFalse(keyDowned, "nothing happens when a key was pressed");
            });
            it("can set a callback to be called when the key is released", function () {
                var keyUped = false;
                var callback = function (code, event) {
                    keyUped = true;
                    chai_1.assert.strictEqual(code, keyCodeToSend, "correct keycode was passed");
                    chai_1.assert.isNotNull(event, "key event was passed to the callback");
                };
                chai_1.assert.strictEqual(keyDispatcher.onKeyUp(callback), keyDispatcher, "setting the keyUp callback returns the dispatcher");
                TestMethods.triggerFakeKeyboardEvent("keyup", body, keyCodeToSend);
                chai_1.assert.isTrue(keyUped, "callback when a key was released");
                keyDispatcher.offKeyUp(callback);
            });
            it("can remove the keyup listener", function () {
                var keyUped = false;
                var callback = function () { return keyUped = true; };
                keyDispatcher.onKeyUp(callback);
                TestMethods.triggerFakeKeyboardEvent("keyup", body, keyCodeToSend);
                chai_1.assert.isTrue(keyUped, "callback when a key was released");
                chai_1.assert.strictEqual(keyDispatcher.offKeyUp(callback), keyDispatcher, "unsetting the keyup callback returns the dispatcher");
                keyUped = false;
                TestMethods.triggerFakeKeyboardEvent("keyup", body, keyCodeToSend);
                chai_1.assert.isFalse(keyUped, "nothing happens when a key was released");
            });
        });
    });
});
