"use strict";
var chai_1 = require("chai");
var Plottable = require("../../src");
var TestMethods = require("../testMethods");
describe("Drawers", function () {
    describe("Area Drawer", function () {
        var data = [["A", "B", "C"]]; // area normally takes single array of data
        var svg;
        var drawer;
        beforeEach(function () {
            svg = TestMethods.generateSVG();
            drawer = new Plottable.Drawers.Area(null);
            drawer.renderArea(svg);
            var drawSteps = [
                {
                    attrToProjector: {},
                    animator: new Plottable.Animators.Null(),
                },
            ];
            drawer.draw(data, drawSteps);
        });
        afterEach(function () {
            if (this.currentTest.state === "passed") {
                svg.remove();
            }
        });
        it("has a stroke of \"none\"", function () {
            chai_1.assert.strictEqual(drawer.selection().style("stroke"), "none");
        });
        it("retrieves the same path regardless of requested selection index", function () {
            var expectedSelection = svg.selectAll("path");
            data[0].forEach(function (datum, index) {
                var selectionForIndex = drawer.selectionForIndex(index);
                chai_1.assert.strictEqual(selectionForIndex.size(), 1, "selection for index " + index + " contains only one element");
                chai_1.assert.strictEqual(selectionForIndex.node(), expectedSelection.node(), "selection for index " + index + " contains the correct element");
            });
        });
    });
});
