"use strict";
var chai_1 = require("chai");
var d3 = require("d3");
var sinon = require("sinon");
var Plottable = require("../../src");
var TestMethods = require("../testMethods");
describe("Drawers", function () {
    describe("Line Drawer", function () {
        var data = [["A", "B", "C"]]; // line normally takes single array of data
        var svg;
        var drawer;
        var drawSteps = [
            {
                attrToProjector: {},
                animator: new Plottable.Animators.Null(),
            },
        ];
        var d3LineFactorySpy;
        beforeEach(function () {
            svg = TestMethods.generateSVG();
            drawer = new Plottable.Drawers.Line(null, function () { return d3.line(); });
            d3LineFactorySpy = sinon.spy(drawer, "_d3LineFactory");
            drawer.renderArea(svg);
        });
        afterEach(function () {
            if (this.currentTest.state === "passed") {
                svg.remove();
            }
        });
        it("has a fill of \"none\"", function () {
            drawer.draw(data, drawSteps);
            chai_1.assert.strictEqual(drawer.selection().style("fill"), "none");
        });
        it("retrieves the same path regardless of requested selection index", function () {
            drawer.draw(data, drawSteps);
            var expectedSelection = svg.selectAll("path");
            data[0].forEach(function (datum, index) {
                var selectionForIndex = drawer.selectionForIndex(index);
                chai_1.assert.strictEqual(selectionForIndex.size(), 1, "selection for index " + index + " contains only one element");
                chai_1.assert.strictEqual(selectionForIndex.node(), expectedSelection.node(), "selection for index " + index + " contains the correct element");
            });
        });
        it("uses the line factory during canvas drawing", function () {
            var canvas = d3.select(document.createElement("canvas"));
            drawer.canvas(canvas);
            drawer.draw(data, drawSteps);
            chai_1.assert.isTrue(d3LineFactorySpy.called, "got a line factory");
        });
    });
});
