"use strict";
var chai_1 = require("chai");
var Plottable = require("../../src");
var TestMethods = require("../testMethods");
describe("Plots", function () {
    describe("StackedBar Plot Stacking", function () {
        var stackedPlot;
        beforeEach(function () {
            var xScale = new Plottable.Scales.Linear();
            var yScale = new Plottable.Scales.Linear();
            stackedPlot = new Plottable.Plots.StackedBar();
            stackedPlot.x(function (d) { return d.x; }, xScale);
            stackedPlot.y(function (d) { return d.y; }, yScale);
        });
        it("uses positive offset on stacking the 0 value", function () {
            var data0 = [
                { x: 1, y: 1 },
                { x: 3, y: 1 },
            ];
            var data1 = [
                { x: 1, y: 0 },
                { x: 3, y: 1 },
            ];
            var data2 = [
                { x: 1, y: -1 },
                { x: 3, y: 1 },
            ];
            var data3 = [
                { x: 1, y: 1 },
                { x: 3, y: 1 },
            ];
            var data4 = [
                { x: 1, y: 0 },
                { x: 3, y: 1 },
            ];
            var ds0 = new Plottable.Dataset(data0);
            var ds1 = new Plottable.Dataset(data1);
            var ds2 = new Plottable.Dataset(data2);
            var ds3 = new Plottable.Dataset(data3);
            var ds4 = new Plottable.Dataset(data4);
            stackedPlot.addDataset(ds0);
            stackedPlot.addDataset(ds1);
            stackedPlot.addDataset(ds2);
            stackedPlot.addDataset(ds3);
            stackedPlot.addDataset(ds4);
            var stackOffset1 = stackedPlot._stackingResult.get(ds1);
            var stackOffset4 = stackedPlot._stackingResult.get(ds4);
            chai_1.assert.strictEqual(stackOffset1.get("1").offset, 1, "positive offset was used");
            chai_1.assert.strictEqual(stackOffset4.get("1").offset, 2, "positive offset was used");
        });
        it("strings are coerced to numbers for stacking", function () {
            var data0 = [
                { x: 1, y: "-2" },
            ];
            var data1 = [
                { x: 1, y: "3" },
            ];
            var data2 = [
                { x: 1, y: "-1" },
            ];
            var data3 = [
                { x: 1, y: "5" },
            ];
            var data4 = [
                { x: 1, y: "1" },
            ];
            var data5 = [
                { x: 1, y: "-1" },
            ];
            var ds0 = new Plottable.Dataset(data0);
            var ds1 = new Plottable.Dataset(data1);
            var ds2 = new Plottable.Dataset(data2);
            var ds3 = new Plottable.Dataset(data3);
            var ds4 = new Plottable.Dataset(data4);
            var ds5 = new Plottable.Dataset(data5);
            stackedPlot.addDataset(ds0);
            stackedPlot.addDataset(ds1);
            stackedPlot.addDataset(ds2);
            stackedPlot.addDataset(ds3);
            stackedPlot.addDataset(ds4);
            stackedPlot.addDataset(ds5);
            var stackOffset2 = stackedPlot._stackingResult.get(ds2);
            var stackOffset3 = stackedPlot._stackingResult.get(ds3);
            var stackOffset4 = stackedPlot._stackingResult.get(ds4);
            var stackOffset5 = stackedPlot._stackingResult.get(ds5);
            chai_1.assert.strictEqual(stackOffset2.get("1").offset, -2, "stacking on data1 numerical y value");
            chai_1.assert.strictEqual(stackOffset3.get("1").offset, 3, "stacking on data2 numerical y value");
            chai_1.assert.strictEqual(stackOffset4.get("1").offset, 8, "stacking on data1 + data3 numerical y values");
            chai_1.assert.strictEqual(stackOffset5.get("1").offset, -3, "stacking on data2 + data4 numerical y values");
            chai_1.assert.deepEqual(stackedPlot._stackedExtent, [-4, 9], "stacked extent is as normal");
        });
        it("stacks correctly on empty data", function () {
            var dataset1 = new Plottable.Dataset([]);
            var dataset2 = new Plottable.Dataset([]);
            chai_1.assert.doesNotThrow(function () { return stackedPlot.addDataset(dataset1); }, Error);
            chai_1.assert.doesNotThrow(function () { return stackedPlot.addDataset(dataset2); }, Error);
        });
        it("does not crash on stacking no datasets", function () {
            var dataset1 = new Plottable.Dataset([
                { x: 1, y: -2 },
            ]);
            stackedPlot.addDataset(dataset1);
            chai_1.assert.doesNotThrow(function () { return stackedPlot.removeDataset(dataset1); }, Error);
        });
    });
    describe("StackedArea Plot Stacking", function () {
        var stackedPlot;
        beforeEach(function () {
            var xScale = new Plottable.Scales.Linear();
            var yScale = new Plottable.Scales.Linear();
            stackedPlot = new Plottable.Plots.StackedArea();
            stackedPlot.x(function (d) { return d.x; }, xScale);
            stackedPlot.y(function (d) { return d.y; }, yScale);
        });
        it("uses positive offset on stacking the 0 value", function () {
            var data0 = [
                { x: 1, y: 1 },
                { x: 3, y: 1 },
            ];
            var data1 = [
                { x: 1, y: 0 },
                { x: 3, y: 1 },
            ];
            var data2 = [
                { x: 1, y: -1 },
                { x: 3, y: 1 },
            ];
            var data3 = [
                { x: 1, y: 1 },
                { x: 3, y: 1 },
            ];
            var data4 = [
                { x: 1, y: 0 },
                { x: 3, y: 1 },
            ];
            var ds0 = new Plottable.Dataset(data0);
            var ds1 = new Plottable.Dataset(data1);
            var ds2 = new Plottable.Dataset(data2);
            var ds3 = new Plottable.Dataset(data3);
            var ds4 = new Plottable.Dataset(data4);
            stackedPlot.addDataset(ds0);
            stackedPlot.addDataset(ds1);
            stackedPlot.addDataset(ds2);
            stackedPlot.addDataset(ds3);
            stackedPlot.addDataset(ds4);
            var stackOffset1 = stackedPlot._stackingResult.get(ds1);
            var stackOffset4 = stackedPlot._stackingResult.get(ds4);
            chai_1.assert.strictEqual(stackOffset1.get("1").offset, 1, "positive offset was used");
            chai_1.assert.strictEqual(stackOffset4.get("1").offset, 2, "positive offset was used");
        });
        it("strings are coerced to numbers for stacking", function () {
            var data0 = [
                { x: 1, y: "-2" },
            ];
            var data1 = [
                { x: 1, y: "3" },
            ];
            var data2 = [
                { x: 1, y: "-1" },
            ];
            var data3 = [
                { x: 1, y: "5" },
            ];
            var data4 = [
                { x: 1, y: "1" },
            ];
            var data5 = [
                { x: 1, y: "-1" },
            ];
            var ds0 = new Plottable.Dataset(data0);
            var ds1 = new Plottable.Dataset(data1);
            var ds2 = new Plottable.Dataset(data2);
            var ds3 = new Plottable.Dataset(data3);
            var ds4 = new Plottable.Dataset(data4);
            var ds5 = new Plottable.Dataset(data5);
            stackedPlot.addDataset(ds0);
            stackedPlot.addDataset(ds1);
            stackedPlot.addDataset(ds2);
            stackedPlot.addDataset(ds3);
            stackedPlot.addDataset(ds4);
            stackedPlot.addDataset(ds5);
            var stackOffset2 = stackedPlot._stackingResult.get(ds2);
            var stackOffset3 = stackedPlot._stackingResult.get(ds3);
            var stackOffset4 = stackedPlot._stackingResult.get(ds4);
            var stackOffset5 = stackedPlot._stackingResult.get(ds5);
            chai_1.assert.strictEqual(stackOffset2.get("1").offset, -2, "stacking on data1 numerical y value");
            chai_1.assert.strictEqual(stackOffset3.get("1").offset, 3, "stacking on data2 numerical y value");
            chai_1.assert.strictEqual(stackOffset4.get("1").offset, 8, "stacking on data1 + data3 numerical y values");
            chai_1.assert.strictEqual(stackOffset5.get("1").offset, -3, "stacking on data2 + data4 numerical y values");
            chai_1.assert.deepEqual(stackedPlot._stackedExtent, [-4, 9], "stacked extent is as normal");
        });
        it("stacks correctly on empty data", function () {
            var dataset1 = new Plottable.Dataset([]);
            var dataset2 = new Plottable.Dataset([]);
            chai_1.assert.doesNotThrow(function () { return stackedPlot.addDataset(dataset1); }, Error);
            chai_1.assert.doesNotThrow(function () { return stackedPlot.addDataset(dataset2); }, Error);
        });
        it("does not crash on stacking no datasets", function () {
            var dataset1 = new Plottable.Dataset([
                { x: 1, y: -2 },
            ]);
            stackedPlot.addDataset(dataset1);
            chai_1.assert.doesNotThrow(function () { return stackedPlot.removeDataset(dataset1); }, Error);
        });
    });
    describe("auto scale domain on numeric", function () {
        var div;
        var DIV_WIDTH = 600;
        var DIV_HEIGHT = 400;
        var yScale;
        var xScale;
        var dataset1;
        var dataset2;
        beforeEach(function () {
            div = TestMethods.generateDiv(DIV_WIDTH, DIV_HEIGHT);
            xScale = new Plottable.Scales.Linear();
            xScale.domain([1, 2]);
            yScale = new Plottable.Scales.Linear();
            dataset1 = new Plottable.Dataset([
                { x: 1, y: 1 },
                { x: 2, y: 2 },
                { x: 3, y: 8 },
            ]);
            dataset2 = new Plottable.Dataset([
                { x: 1, y: 2 },
                { x: 2, y: 2 },
                { x: 3, y: 3 },
            ]);
        });
        it("auto scales correctly on stacked area", function () {
            var plot = new Plottable.Plots.StackedArea();
            plot.addDataset(dataset1)
                .addDataset(dataset2);
            plot.x(function (d) { return d.x; }, xScale)
                .y(function (d) { return d.y; }, yScale)
                .autorangeMode("y");
            plot.renderTo(div);
            chai_1.assert.deepEqual(yScale.domain(), [0, 4.5], "auto scales takes stacking into account");
            div.remove();
        });
        it("auto scales correctly on stacked bar", function () {
            var plot = new Plottable.Plots.StackedBar();
            plot.addDataset(dataset1)
                .addDataset(dataset2);
            plot.x(function (d) { return d.x; }, xScale)
                .y(function (d) { return d.y; }, yScale)
                .autorangeMode("y");
            plot.renderTo(div);
            chai_1.assert.deepEqual(yScale.domain(), [0, 4.5], "auto scales takes stacking into account");
            div.remove();
        });
    });
    describe("auto scale domain on Category", function () {
        var div;
        var DIV_WIDTH = 600;
        var DIV_HEIGHT = 400;
        var yScale;
        var xScale;
        var dataset1;
        var dataset2;
        beforeEach(function () {
            div = TestMethods.generateDiv(DIV_WIDTH, DIV_HEIGHT);
            xScale = new Plottable.Scales.Category().domain(["a", "b"]);
            yScale = new Plottable.Scales.Linear();
            dataset1 = new Plottable.Dataset([
                { x: "a", y: 1 },
                { x: "b", y: 2 },
                { x: "c", y: 8 },
            ]);
            dataset2 = new Plottable.Dataset([
                { x: "a", y: 2 },
                { x: "b", y: 2 },
                { x: "c", y: 3 },
            ]);
        });
        it("auto scales correctly on stacked bar", function () {
            var plot = new Plottable.Plots.StackedBar();
            plot.addDataset(dataset1)
                .addDataset(dataset2);
            plot.x(function (d) { return d.x; }, xScale)
                .y(function (d) { return d.y; }, yScale)
                .autorangeMode("y");
            plot.renderTo(div);
            chai_1.assert.deepEqual(yScale.domain(), [0, 4.5], "auto scales takes stacking into account");
            div.remove();
        });
        it("auto scales correctly on stacked area", function () {
            var plot = new Plottable.Plots.StackedArea();
            plot.addDataset(dataset1)
                .addDataset(dataset2);
            plot.x(function (d) { return d.x; }, xScale)
                .y(function (d) { return d.y; }, yScale)
                .autorangeMode("y");
            plot.renderTo(div);
            chai_1.assert.deepEqual(yScale.domain(), [0, 4.5], "auto scales takes stacking into account");
            div.remove();
        });
    });
    describe("scale extent updates", function () {
        var div;
        var xScale;
        var yScale;
        var stackedBarPlot;
        beforeEach(function () {
            div = TestMethods.generateDiv(600, 400);
            xScale = new Plottable.Scales.Category();
            yScale = new Plottable.Scales.Linear();
            stackedBarPlot = new Plottable.Plots.StackedBar();
            stackedBarPlot.x(function (d) { return d.key; }, xScale);
            stackedBarPlot.y(function (d) { return d.value; }, yScale);
            stackedBarPlot.renderTo(div);
        });
        afterEach(function () {
            div.remove();
        });
        it("extents are updated as datasets are updated", function () {
            var data1 = [
                { key: "a", value: 1 },
                { key: "b", value: -2 },
            ];
            var data2 = [
                { key: "a", value: 3 },
                { key: "b", value: -4 },
            ];
            var data2B = [
                { key: "a", value: 1 },
                { key: "b", value: -2 },
            ];
            var dataset1 = new Plottable.Dataset(data1);
            var dataset2 = new Plottable.Dataset(data2);
            stackedBarPlot.addDataset(dataset1);
            stackedBarPlot.addDataset(dataset2);
            chai_1.assert.closeTo(yScale.domain()[0], -6, 1, "min stacked extent is as normal");
            chai_1.assert.closeTo(yScale.domain()[1], 4, 1, "max stacked extent is as normal");
            dataset2.data(data2B);
            chai_1.assert.closeTo(yScale.domain()[0], -4, 1, "min stacked extent decreases in magnitude");
            chai_1.assert.closeTo(yScale.domain()[1], 2, 1, "max stacked extent decreases in magnitude");
        });
    });
});
