"use strict";
var chai_1 = require("chai");
var Plottable = require("../../src");
describe("Scales", function () {
    describe("QuantitativeScale", function () {
        describe("computing extents", function () {
            // HACKHACK #2336: QuantitativeScales don't take min/max of stringy values correctly
            it.skip("gives the minimum and maxiumum when the domain is stringy", function () {
                var values = ["11", "3", "2", "1"];
                var scale = new Plottable.QuantitativeScale();
                var computedExtent = scale.extentOfValues(values);
                chai_1.assert.deepEqual(computedExtent, ["1", "11"], "the extent is the miminum and the maximum values");
            });
            it("gives the minimum and maxiumum when the domain is numeric", function () {
                var values = [11, 3, 2, 1];
                var scale = new Plottable.QuantitativeScale();
                var computedExtent = scale.extentOfValues(values);
                chai_1.assert.deepEqual(computedExtent, [1, 11], "the extent is the miminum and the maximum values");
            });
            it("ignores NaN, null, and undefined values when computing the extent", function () {
                var values = [NaN, null, undefined, 1, 11];
                var scale = new Plottable.QuantitativeScale();
                var computedExtent = scale.extentOfValues(values);
                chai_1.assert.deepEqual(computedExtent, [1, 11], "the extent is the minimum and the maximum values");
            });
            it("ignores infinite values when computing the extent", function () {
                var values = [Infinity, -Infinity, 1, 11];
                var scale = new Plottable.QuantitativeScale();
                var computedExtent = scale.extentOfValues(values);
                chai_1.assert.deepEqual(computedExtent, [1, 11], "the extent is the minimum and the maximum values");
            });
        });
        describe("padding", function () {
            it("rejects negative values for padding", function () {
                var scale = new Plottable.QuantitativeScale();
                chai_1.assert.throws(function () { return scale.padProportion(-0.05); }, Error, "must be non-negative");
            });
        });
        describe("tick generation", function () {
            it("can set and get a TickGenerator", function () {
                var scale = new Plottable.QuantitativeScale();
                var tickGenerator = function () { return []; };
                chai_1.assert.strictEqual(scale.tickGenerator(tickGenerator), scale, "setting the TickGenerator returns the QuantitativeScale");
                chai_1.assert.strictEqual(scale.tickGenerator(), tickGenerator, "getter mode returns the set TickGenerator");
            });
            it("uses its TickGenerator to create ticks", function () {
                var scale = new Plottable.QuantitativeScale();
                var expectedTicks = [1, 2, 99];
                var tickGenerator = function (passedScale) {
                    chai_1.assert.strictEqual(passedScale, scale, "TickGenerator was passed the QuantitativeScale it was attached to");
                    return expectedTicks;
                };
                scale.tickGenerator(tickGenerator);
                var generatedTicks = scale.ticks();
                chai_1.assert.deepEqual(generatedTicks, expectedTicks, "returned ticks generated by the TickGenerator");
            });
        });
    });
});
