import { SimpleSelection } from "../src/core/interfaces";
import * as d3 from "d3";
import * as Plottable from "../src";
export declare function generateDiv(width?: number, height?: number): d3.Selection<HTMLDivElement, void | {}, any, any>;
export declare function generateSVG(width?: number, height?: number): d3.Selection<SVGSVGElement, void | {}, any, any>;
export declare function getElementParent(): SimpleSelection<void>;
export declare function isInDOM(component: Plottable.Component): boolean;
export declare function verifySpaceRequest(sr: Plottable.SpaceRequest, expectedMinWidth: number, expectedMinHeight: number, message: string): void;
export declare function fixComponentSize(c: Plottable.Component, fixedWidth?: number, fixedHeight?: number): Plottable.Component;
export declare function makeFixedSizeComponent(fixedWidth?: number, fixedHeight?: number): Plottable.Component;
export declare function getTranslate(element: SimpleSelection<void>): [number, number];
export declare function assertBBoxEquivalence(bbox: SVGRect, widthAndHeightPair: number[], message: string): void;
export declare function assertBBoxInclusion(outerEl: SimpleSelection<void>, innerEl: SimpleSelection<void>): void;
export declare function assertBBoxNonIntersection(firstEl: SimpleSelection<void>, secondEl: SimpleSelection<void>): void;
export declare function assertPointsClose(actual: Plottable.Point, expected: Plottable.Point, epsilon: number, message: String): void;
export declare function assertWidthHeight(el: SimpleSelection<void>, widthExpected: number, heightExpected: number, message: string): void;
export declare function assertLineAttrs(line: SimpleSelection<void>, expectedAttrs: {
    x1: number;
    y1: number;
    x2: number;
    y2: number;
}, message: string): void;
export declare function assertEntitiesEqual(actual: Plottable.Entity<Plottable.Component>, expected: Plottable.Entity<Plottable.Component>, msg: string): void;
export declare function assertPlotEntitiesEqual(actual: Plottable.Plots.PlotEntity, expected: Plottable.Plots.PlotEntity, msg: string): void;
export declare function makeLinearSeries(n: number): {
    x: number;
    y: number;
}[];
export declare function makeQuadraticSeries(n: number): {
    x: number;
    y: number;
}[];
export declare function normalizePath(pathString: string): string;
/**
 * Decomposes a normalized path-string ("d" attribute from a <path>)
 * to an array of command-argument pairs:
 * {
   *   command: string;
   *   arguments: number[];
   * }[]
 */
export declare function decomposePath(normalizedPathString: string): {
    command: string;
    arguments: number[];
}[];
export declare function numAttr(s: SimpleSelection<void>, a: string): number;
export declare function triggerFakeUIEvent(type: string, target: SimpleSelection<void>): void;
export declare function triggerFakeMouseEvent(type: string, target: SimpleSelection<void>, relativeX: number, relativeY: number, button?: number): void;
export declare function triggerFakeDragSequence(target: SimpleSelection<void>, start: Plottable.Point, end: Plottable.Point, numSteps?: number): void;
export declare function isIE(): boolean;
export declare function triggerFakeWheelEvent(type: string, target: SimpleSelection<void>, relativeX: number, relativeY: number, deltaY: number): void;
export declare function triggerFakeTouchEvent(type: string, target: SimpleSelection<void>, touchPoints: Plottable.Point[], ids?: number[]): void;
export declare enum InteractionMode {
    Mouse = 0,
    Touch = 1,
}
export declare enum InteractionType {
    Start = 0,
    Move = 1,
    End = 2,
}
export declare function triggerFakeInteractionEvent(mode: InteractionMode, type: InteractionType, target: SimpleSelection<void>, relativeX: number, relativeY: number): void;
export declare function triggerFakeKeyboardEvent(type: string, target: SimpleSelection<void>, keyCode: number, options?: {
    [key: string]: any;
}): void;
export declare function assertAreaPathCloseTo(actualPath: string, expectedPath: string, precision: number, msg: string): void;
export declare type RGB = {
    red: number;
    green: number;
    blue: number;
};
export declare function colorHexToRGB(hex: string): RGB;
export declare function colorRGBToHex(rgb: RGB): string;
export declare function assertWarns(fn: Function, warningMessage: string, assertMessage: string): void;
export declare function areaVertices(areaSelection: SimpleSelection<any>): Plottable.Point[];
export declare function assertPathEqualToDataPoints(path: string, data: {
    x: number;
    y: number;
}[], xScale: Plottable.QuantitativeScale<any>, yScale: Plottable.QuantitativeScale<any>): void;
