"use strict";
var chai_1 = require("chai");
var Plottable = require("../../src");
describe("Map", function () {
    it("set() and get()", function () {
        var map = new Plottable.Utils.Map();
        var key1 = "key1";
        var value1 = "1";
        map.set(key1, value1);
        chai_1.assert.strictEqual(map.get(key1), value1, "value was successfully set on the Map");
        var value1b = "1b";
        map.set(key1, value1b);
        chai_1.assert.strictEqual(map.get(key1), value1b, "overwrote old value with new one");
        var key2 = "key2";
        chai_1.assert.isUndefined(map.get(key2), "returns undefined if key is not present in the Map");
    });
    it("chained set() works", function () {
        var map = new Plottable.Utils.Map();
        map.set(1, 1).set(2, 3);
        chai_1.assert.strictEqual(map.get(1), 1, "First value was set");
        chai_1.assert.strictEqual(map.get(2), 3, "Second value was set");
    });
    it("has()", function () {
        var map = new Plottable.Utils.Map();
        var key1 = "key1";
        var value1 = "1";
        chai_1.assert.isFalse(map.has(key1), "returns false if the key has not been set");
        map.set(key1, value1);
        chai_1.assert.isTrue(map.has(key1), "returns true if the key has been set");
        map.set(key1, undefined);
        chai_1.assert.isTrue(map.has(key1), "returns true if the value is explicitly set to undefined");
    });
    it("forEach()", function () {
        var map = new Plottable.Utils.Map();
        var keys = ["Tom", "Jerry"];
        var values = [1, 2];
        map.set(keys[0], values[0]);
        map.set(keys[1], values[1]);
        var index = 0;
        map.forEach(function (value, key, mp) {
            chai_1.assert.strictEqual(value, values[index], "Value " + index + " is the expected one");
            chai_1.assert.strictEqual(key, keys[index], "Key " + index + " is the expected one");
            chai_1.assert.strictEqual(mp, map, "The correct map is passed as the third argument");
            index++;
        });
        chai_1.assert.strictEqual(index, keys.length, "The expected number of iterations executed in the forEach");
    });
    it("forEach() not called on empty map", function () {
        var map = new Plottable.Utils.Map();
        map.forEach(function (value, key, mp) {
            chai_1.assert.notOk(true, "forEach should not be called because the map is empty");
        });
    });
    it("forEach() can force the this context", function () {
        var map = new Plottable.Utils.Map();
        map.set(1, 2);
        var thisArg = { "foo": "bar" };
        map.forEach(function (value, key, mp) {
            chai_1.assert.strictEqual(this, thisArg, "The correct this context is forced");
            chai_1.assert.strictEqual(this.foo, "bar", "The forced context object behaves correctly");
        }, thisArg);
    });
    it("delete()", function () {
        var map = new Plottable.Utils.Map();
        var key1 = "key1";
        var value1 = "1";
        map.set(key1, value1);
        chai_1.assert.isTrue(map.delete(key1), "returns true if the key was present in the Map");
        chai_1.assert.isFalse(map.has(key1), "key is no longer present in the Map");
        chai_1.assert.isFalse(map.delete(key1), "returns false if the key was not present in the Map");
    });
});
