"use strict";
var chai_1 = require("chai");
var Plottable = require("../../src");
describe("Utils", function () {
    describe("Set", function () {
        it("add()", function () {
            var set = new Plottable.Utils.Set();
            var value1 = { value: "one" };
            set.add(value1);
            chai_1.assert.strictEqual(set.size, 1, "set contains one value");
            set.add(value1);
            chai_1.assert.strictEqual(set.size, 1, "same value is not added twice");
            var value2 = { value: "two" };
            set.add(value2);
            chai_1.assert.strictEqual(set.size, 2, "set now contains two values");
        });
        it("delete()", function () {
            var set = new Plottable.Utils.Set();
            var value1 = { value: "one" };
            set.add(value1);
            chai_1.assert.strictEqual(set.size, 1, "set contains one value after adding");
            set.delete(value1);
            chai_1.assert.strictEqual(set.size, 0, "value was delete");
            set.add(value1);
            var value2 = { value: "two" };
            set.delete(value2);
            chai_1.assert.strictEqual(set.size, 1, "removing a non-existent value does nothing");
        });
        it("has()", function () {
            var set = new Plottable.Utils.Set();
            var value1 = { value: "one" };
            set.add(value1);
            chai_1.assert.isTrue(set.has(value1), "correctly checks that value is in the set");
            var similarValue1 = { value: "one" };
            chai_1.assert.isFalse(set.has(similarValue1), "correctly determines that similar object is not in the set");
            set.delete(value1);
            chai_1.assert.isFalse(set.has(value1), "correctly checks that value is no longer in the set");
        });
        it("forEach()", function () {
            var set = new Plottable.Utils.Set();
            var values = [1, "2"];
            set.add(values[0]);
            set.add(values[1]);
            var index = 0;
            set.forEach(function (value1, value2, passedSet) {
                // HACKHACK: Safari bug #21489317: Safari passes undefined instead of a duplicate value for value2.
                if (value2 !== undefined) {
                    chai_1.assert.strictEqual(value1, value2, "The two value arguments passed to the callback are the same");
                }
                chai_1.assert.strictEqual(value1, values[index], "Value " + index + " is the expected one");
                chai_1.assert.strictEqual(passedSet, set, "The correct Set is passed as the third argument");
                index++;
            });
            chai_1.assert.strictEqual(index, values.length, "The expected number of iterations executed in the forEach");
        });
        it("forEach() not called on empty set", function () {
            var set = new Plottable.Utils.Set();
            set.forEach(function (value, value2, mp) {
                chai_1.assert.notOk(true, "forEach should not be called because the set is empty");
            });
        });
        it("forEach() can force the this context", function () {
            var set = new Plottable.Utils.Set();
            set.add(1);
            var thisArg = { "foo": "bar" };
            set.forEach(function (value, value2, mp) {
                chai_1.assert.strictEqual(this, thisArg, "The correct this context is forced");
                chai_1.assert.strictEqual(this.foo, "bar", "The forced context object behaves correctly");
            }, thisArg);
        });
    });
});
