"use strict";
var sinon = require("sinon");
var chai_1 = require("chai");
var Plottable = require("../../src");
var TestMethods = require("../testMethods");
describe("Translator", function () {
    it("getTranslator() creates only one Translator per html root", function () {
        var div = TestMethods.generateDiv();
        var component = new Plottable.Component();
        sinon.stub(component, "rootElement", function () { return div; });
        var t1 = Plottable.Utils.getTranslator(component);
        chai_1.assert.isNotNull(t1, "created a new Translator on a <svg>");
        var t2 = Plottable.Utils.getTranslator(component);
        chai_1.assert.strictEqual(t1, t2, "returned the existing Translator if called again with same <svg>");
        div.remove();
    });
    it("converts points to html-space correctly", function () {
        var div = TestMethods.generateDiv();
        div.style("position", "relative");
        var component = new Plottable.Component();
        sinon.stub(component, "rootElement", function () { return div; });
        var divOrigin = {
            x: 19,
            y: 85,
        };
        var rect = div.append("div").styles({
            left: divOrigin.x + "px",
            position: "absolute",
            top: divOrigin.y + "px",
            width: "30px",
            height: "30px",
        });
        var translator = Plottable.Utils.getTranslator(component);
        var boundingClientRect = rect.node().getBoundingClientRect();
        var computedOrigin = translator.computePosition(boundingClientRect.left, boundingClientRect.top);
        TestMethods.assertPointsClose(computedOrigin, divOrigin, 0.5, "translates client coordinates to <svg> coordinates correctly");
        div.remove();
    });
    it("getTranslator() creates only one Translator per <svg>", function () {
        var div = TestMethods.generateDiv();
        var component = new Plottable.Component();
        sinon.stub(component, "rootElement", function () { return div; });
        var t1 = Plottable.Utils.getTranslator(component);
        chai_1.assert.isNotNull(t1, "created a new Translator on a <svg>");
        var t2 = Plottable.Utils.getTranslator(component);
        chai_1.assert.strictEqual(t1, t2, "returned the existing Translator if called again with same <svg>");
        div.remove();
    });
    it("converts points to <svg>-space correctly", function () {
        var svg = TestMethods.generateSVG();
        var component = new Plottable.Component();
        sinon.stub(component, "rootElement", function () { return svg; });
        var rectOrigin = {
            x: 19,
            y: 85,
        };
        var rect = svg.append("rect").attrs({
            x: rectOrigin.x,
            y: rectOrigin.y,
            width: 30,
            height: 30,
        });
        var translator = Plottable.Utils.getTranslator(component);
        var rectBCR = rect.node().getBoundingClientRect();
        var computedOrigin = translator.computePosition(rectBCR.left, rectBCR.top);
        TestMethods.assertPointsClose(computedOrigin, rectOrigin, 0.5, "translates client coordinates to <svg> coordinates correctly");
        svg.remove();
    });
});
